@@ -2,7 +2,7 @@
 ** DVIToSVGActions.cpp                                                  **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -34,8 +34,7 @@ using namespace std;
 
 void DVIToSVGActions::reset() {
 	FontManager::instance().resetUsedChars();
-	_bbox = BoundingBox();
-	_currentFontNum = -1;
+	_bbox.invalidate();
 	_bgcolor = Color::TRANSPARENT;
 }
 
@@ -184,7 +183,6 @@ void DVIToSVGActions::setRule (double x, double y, double height, double width)
  *  @param[in] num unique number of the font in the DVI file (not necessarily equal to the DVI font number)
  *  @param[in] font pointer to the font object (always represents a physical font and never a virtual font) */
 void DVIToSVGActions::setFont (int num, const Font &font) {
-	_currentFontNum = num;
 	_svg.setFont(num, font);
 }
 
@@ -215,6 +213,7 @@ void DVIToSVGActions::beginPage (unsigned pageno, const vector<int32_t>&) {
 	_svg.newPage(++_pageCount);
 	_bbox = BoundingBox();  // clear bounding box
 	_boxes.clear();
+	setMatrix(Matrix(1));
 	SpecialManager::instance().notifyBeginPage(pageno, *this);
 }
 
@@ -247,14 +246,14 @@ void DVIToSVGActions::setBgColor (const Color &color) {
 }
 
 
-void DVIToSVGActions::embed(const BoundingBox &bbox) {
+void DVIToSVGActions::embed (const BoundingBox &bbox) {
 	_bbox.embed(bbox);
 	for (auto &strboxpair : _boxes)
 		strboxpair.second.embed(bbox);
 }
 
 
-void DVIToSVGActions::embed(const DPair& p, double r) {
+void DVIToSVGActions::embed (const DPair& p, double r) {
 	if (r == 0)
 		_bbox.embed(p);
 	else
@@ -264,7 +263,7 @@ void DVIToSVGActions::embed(const DPair& p, double r) {
 }
 
 
-BoundingBox& DVIToSVGActions::bbox(const string& name, bool reset) {
+BoundingBox& DVIToSVGActions::bbox (const string& name, bool reset) {
 	BoundingBox &box = _boxes[name];
 	if (reset)
 		box = BoundingBox();
