@@ -2,7 +2,7 @@
 ** FilePath.hpp                                                         **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -38,14 +38,17 @@ class FilePath {
 			std::string _dirstr;
 	};
 
+	public:
+		enum PathType {PT_DIR, PT_FILE};
+
 	public:
 		FilePath () =default;
 		explicit FilePath (const std::string &path) {set(path);}
-		FilePath (const std::string &path, bool isfile) : FilePath(path, isfile, "") {}
-		FilePath (const std::string &path, bool isfile, const std::string &current_dir);
+		FilePath (const std::string &path, PathType type) : FilePath(path, type, "") {}
+		FilePath (const std::string &path, PathType type, const std::string &current_dir);
 		void set (const std::string &path);
-		void set (const std::string &path, bool isfile);
-		void set (const std::string &path, bool isfile, const std::string &current_dir);
+		void set (const std::string &path, PathType type);
+		void set (const std::string &path, PathType type, const std::string &current_dir);
 		std::string absolute (bool with_filename=true) const;
 		std::string relative (std::string reldir="", bool with_filename=true) const;
 		std::string relative (const FilePath &filepath, bool with_filename=true) const;
@@ -62,7 +65,7 @@ class FilePath {
 		static bool isAbsolute (std::string path);
 
 	protected:
-		void init (std::string path, bool isfile, std::string current_dir);
+		void init (std::string path, PathType type, std::string current_dir);
 		void add (const std::string &elem);
 
 	private:
