@@ -2,7 +2,7 @@
 ** FontMap.hpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -25,10 +25,13 @@
 #include <ostream>
 #include <string>
 #include <unordered_map>
+#include <vector>
 #include "FontStyle.hpp"
+#include "MapLine.hpp"
+#include "MessageException.hpp"
 
+class FilePath;
 struct FontEncoding;
-class MapLine;
 class Subfont;
 
 class FontMap {
@@ -48,11 +51,12 @@ class FontMap {
 
 	public:
 		enum class Mode {APPEND, REMOVE, REPLACE};
+		enum class FirstIncludeMode {OFF, ACTIVE, DONE};
 
 		static FontMap& instance ();
-		bool read (const std::string &fname, Mode mode);
-		bool read (const std::string &fname, char modechar);
-		bool read (const std::string &fname_seq);
+		bool read (const std::string &fname, Mode mode, std::vector<std::string> *includedFilesRef=nullptr);
+		bool read (const std::string &fname, char modechar, std::vector<std::string> *includedFilesRef=nullptr);
+		bool read (const std::string &fname_seq, bool warn=false);
 		void readdir (const std::string &dirname);
 		bool apply (const MapLine &mapline, Mode mode);
 		bool apply (const MapLine &mapline, char modechar);
@@ -66,9 +70,24 @@ class FontMap {
 
 	protected:
 		FontMap () =default;
+		void include (std::string line, const FilePath &includingFile, std::vector<std::string> &includedFiles);
+		void includefirst (std::string line, const FilePath &includingFile, std::vector<std::string> &includedFiles);
 
 	private:
 		std::unordered_map<std::string,std::unique_ptr<Entry>> _entries;
+		FirstIncludeMode _firstincludeMode = FirstIncludeMode::OFF;
+};
+
+class FontMapException : public MapLineException {
+	public:
+		enum class Cause {UNSPECIFIED, FILE_ACCESS_ERROR};
+
+		FontMapException (const std::string &msg, Cause cause) : MapLineException(msg), _cause(cause) {}
+		explicit FontMapException (const std::string &msg) : FontMapException(msg, Cause::UNSPECIFIED) {}
+		Cause cause () const {return _cause;}
+
+	private:
+		Cause _cause = FontMapException::Cause::UNSPECIFIED;
 };
 
 #endif
