@@ -2,7 +2,7 @@
 ** TFM.hpp                                                              **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -30,10 +30,10 @@
 
 class StreamReader;
 
-class TFM : public FontMetrics
-{
+class TFM : public FontMetrics {
 	public:
-		explicit TFM (std::istream &is);
+		TFM () =default;
+		void read (std::istream &is) override;
 		double getCharWidth (int c) const override;
 		double getCharHeight (int c) const override;
 		double getCharDepth (int c) const override;
@@ -47,28 +47,27 @@ class TFM : public FontMetrics
 		double getDescent () const override    {return double(_descent)*_designSize;}
 		bool verticalLayout () const override  {return false;}
 		uint32_t getChecksum () const override {return _checksum;}
-		uint16_t firstChar () const override   {return _firstChar;}
-		uint16_t lastChar () const override    {return _lastChar;}
+		uint32_t firstChar () const override   {return _firstChar;}
+		uint32_t lastChar () const override    {return _lastChar;}
 
 	protected:
-		TFM () : _checksum(0), _firstChar(0), _lastChar(0), _designSize(0), _params(7) {}
 		void readHeader (StreamReader &reader);
 		void readTables (StreamReader &reader, int nw, int nh, int nd, int ni);
 		void readParameters (StreamReader &reader, int np);
-		virtual int charIndex (int c) const;
+		virtual size_t charIndex (int c) const;
 		void setCharRange (int firstchar, int lastchar) {_firstChar=firstchar; _lastChar=lastchar;}
 
 	private:
-		uint32_t _checksum;
-		uint16_t _firstChar, _lastChar;
-		double _designSize;  ///< design size of the font in PS points (72bp = 1in)
+		uint32_t _checksum=0;
+		uint16_t _firstChar=0, _lastChar=0;
+		double _designSize=0;  ///< design size of the font in PS points (72bp = 1in)
 		std::vector<uint32_t>  _charInfoTable;
 		std::vector<FixWord> _widthTable;    ///< character widths in design size units
 		std::vector<FixWord> _heightTable;   ///< character height in design size units
 		std::vector<FixWord> _depthTable;    ///< character depth in design size units
 		std::vector<FixWord> _italicTable;   ///< italic corrections in design size units
 		std::vector<FixWord> _params;        ///< values of the TFM's param section
-		FixWord _ascent, _descent;           ///< max. height and depth
+		FixWord _ascent=0, _descent=0;       ///< max. height and depth
 };
 
 #endif
