@@ -2,7 +2,7 @@
 ** dvisvgm.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -293,7 +293,7 @@ static void init_fontmap (const CommandLine &cmdline) {
 	bool additional = !mapseq.empty() && strchr("+-=", mapseq[0]);
 	if (mapseq.empty() || additional) {
 		bool found = false;
-		for (string mapfile : {"ps2pk", "pdftex", "dvipdfm", "psfonts"}) {
+		for (string mapfile : {"dvisvgm", "ps2pk", "pdftex", "dvipdfm", "psfonts"}) {
 			if ((found = FontMap::instance().read(mapfile+".map")))
 				break;
 		}
@@ -301,7 +301,7 @@ static void init_fontmap (const CommandLine &cmdline) {
 			Message::wstream(true) << "none of the default map files could be found\n";
 	}
 	if (!mapseq.empty())
-		FontMap::instance().read(mapseq);
+		FontMap::instance().read(mapseq, true);
 }
 
 
@@ -438,6 +438,7 @@ static void convert_file (size_t fnameIndex, const CommandLine &cmdline) {
 				? static_cast<ImageToSVG*>(new EPSToSVG(srcin.getFilePath(), out))
 				: static_cast<ImageToSVG*>(new PDFToSVG(srcin.getFilePath(), out)));
 		img2svg->setPageTransformation(get_transformation_string(cmdline));
+		img2svg->setUserMessage(cmdline.messageOpt.value());
 		img2svg->convert(cmdline.pageOpt.value(), &pageinfo);
 		timer_message(start_time, img2svg->isSinglePageFormat() ? nullptr : &pageinfo);
 	}
@@ -451,6 +452,7 @@ static void convert_file (size_t fnameIndex, const CommandLine &cmdline) {
 			dvi2svg.setProcessSpecials(ignore_specials, true);
 			dvi2svg.setPageTransformation(get_transformation_string(cmdline));
 			dvi2svg.setPageSize(cmdline.bboxOpt.value());
+			dvi2svg.setUserMessage(cmdline.messageOpt.value());
 			dvi2svg.convert(cmdline.pageOpt.value(), &pageinfo);
 			timer_message(start_time, &pageinfo);
 		}
